@@ -150,6 +150,8 @@ proc call_page {{useenv ""} {createinterp 0}} {
 			if {$createinterp} {
 				set myinterp [interp create]
 
+				interp alias $myinterp exit {} ::rivetstarkit::destroy_interp $myinterp
+
 				foreach var [list ::starkit::topdir ::auto_path] {
 					if {[namespace qualifiers $var] != ""} {
 						$myinterp eval [list namespace eval [namespace qualifiers $var] ""]
@@ -770,6 +772,10 @@ proc ::rivetstarkit::puts_log {logfd msg} {
 	}
 }
 
+proc ::rivetstarkit::destroy_interp {interp args} {
+	interp delete $interp
+}
+
 proc print_help {} {
 	tcl_puts "Usage: [file tail [info nameofexecutable]] {--server \[--address <address>\]"
 	tcl_puts "       \[--port <port>\] \[--foreground {yes|no}\] \[--init <scp>\]"
@@ -1066,6 +1072,7 @@ proc rivet_cgi_server_request {hostport logfd elogfd pmodel maxthreads httpmode
 				::rivetstarkit::puts_log $elogfd "Creating thread: $threadId"
 
 				# Load the needed packages in the new thread
+				thread::send $threadId [list set ::auto_path $::auto_path]
 				thread::send $threadId [list package require tclrivet]
 				thread::send $threadId [list set ::rivet::parsestack [info script]]
 
@@ -1505,7 +1512,7 @@ if {![info exists ::env(GATEWAY_INTERFACE)]} {
 			exit 0
 		}
 		"--version" {
-			tcl_puts "RivetStarkit version 0.5.0.3157"
+			tcl_puts "RivetStarkit version 0.5.1.0"
 			exit 0
 		}
 		default {
